@@ -295,16 +295,16 @@ class Insight_Definition:
         self.components = r.json()["components"]
 
 
-    def add_list(self, query_id, title_parameter, description_parameter, action_label,
+    def add_list(self, query_id, title_parameter, description_parameter, action_enabled, action_label,
                   action_url, max_results,list_name="List"):
         position = (len(self.components))
         list_id = self.add_component(type="list", position=position)
         self.edit_list(list_id, query_id, title_parameter,
-                       description_parameter, action_label, action_url, max_results, list_name)
+                       description_parameter, action_enabled, action_label, action_url, max_results, list_name)
         return list_id
 
 
-    def edit_list(self, list_id, query_id, title_parameter, description_parameter, action_label,
+    def edit_list(self, list_id, query_id, title_parameter, description_parameter, action_enabled, action_label,
                   action_url, max_results,list_name="List"):
 
         url = self.smart_insight_url + "/definitions/" + self.definition_id + "/lists/" + list_id
@@ -317,8 +317,8 @@ class Insight_Definition:
             "queryId":query_id,
             "title":title_parameter,
             "description":description_parameter,
-            "actionEnabled":True,
-            "actionLabel":action_label,
+            "actionEnabled": action_enabled,
+            "actionLabel": action_label,
             "actionUrl":action_url,
             "maxResults":max_results,
             "valid":True,
@@ -690,7 +690,7 @@ class Insight_Definition:
 
     def delete(self):
 
-        url= self.smart_insight_url+"/definitions/"+self.definition_id
+        url= self.smart_insight_url+"/definitions/"+self.definition_id+"?final=true"
         s = requests.Session()
         s.keep_alive = False
         retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
@@ -1026,10 +1026,49 @@ class Insight_Definition:
             "Authorization": "Bearer" + " " + self._token
         }
         query_url = self.smart_insight_url + '/definitions/' + self.definition_id + '/components/'+component_id
-        #logging.info("URL {}".format(query_url))
+        logging.info("DELETE URL {}".format(query_url))
         r = s.delete(url=query_url, headers=headers)
         r.raise_for_status()
 
+
+    def set_on_demand(self, enabled=True):
+
+        body = {"enabled":enabled}
+
+        url = self.smart_insight_url + "/definitions/" + self.definition_id+ "/intents/status"
+
+        s = requests.Session()
+        s.keep_alive = False
+        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
+        s.mount('https://', HTTPAdapter(max_retries=retries))
+
+        headers = {
+            "Content-Type": "application/json",
+            "Authorization": "Bearer" + " " + self._token
+        }
+
+        r = s.put(url=url, json=body, headers=headers)
+        r.raise_for_status()
+
+    def add_on_demand_queries(self, queries):
+
+        body = {"userQuery": queries}
+
+        url = self.smart_insight_url + "/definitions/" + self.definition_id + "/intents"
+
+        s = requests.Session()
+        s.keep_alive = False
+        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
+        s.mount('https://', HTTPAdapter(max_retries=retries))
+
+        headers = {
+            "Content-Type": "application/json",
+            "Authorization": "Bearer" + " " + self._token
+        }
+
+        r = s.put(url=url, json=body, headers=headers)
+        r.raise_for_status()
+
     def schedule_daily(self, channel_slug, hours, minutues, seconds):
 
         cron = seconds + " " + minutues + " " + hours + " * * *"
