@@ -73,7 +73,7 @@ class Condition:
     operator: Union[SQLOperator, TimeOperator, str]
     value: Optional[List[Union[float, str]]] = None
     type: Optional[str] = None
-    until: Optional[List[Union[float, str]]] = None
+    vuntil: Optional[List[Union[float, str]]] = None
     steps: Optional[str] = None
     interval: Optional[str] = None
     direction: Optional[PeriodOperator] = None
